nanohttp
========

.. image:: http://img.shields.io/pypi/v/nanohttp.svg
   :target: https://pypi.python.org/pypi/nanohttp

.. image:: https://travis-ci.org/Carrene/nanohttp.svg?branch=master
   :target: https://travis-ci.org/Carrene/nanohttp

.. image:: https://coveralls.io/repos/github/Carrene/nanohttp/badge.svg?branch=master
   :target: https://coveralls.io/github/Carrene/nanohttp?branch=master

.. image:: https://badges.gitter.im/Carrene/nanohttp.svg
   :alt: Join the chat at https://gitter.im/Carrene/nanohttp
   :target: https://gitter.im/Carrene/nanohttp?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge

A very micro HTTP framework. `documentation <http://nanohttp.org>`_

